uniform float time;         // bazik preset playback time in seconds
uniform vec2 resolution;    // bazik render width (x) & height (y)

uniform vec3 color1;        // bazik user color 1 (r=x, g=y, b=z)
uniform vec3 color2;        // bazik user color 2 (r=x, g=y, b=z)
uniform vec3 color3;        // bazik user color 3 (r=x, g=y, b=z)
uniform vec3 color4;        // bazik user color 4 (r=x, g=y, b=z)

uniform float eq1;          // bazik 3 band equalizer bass value 0.0 to 1.0
uniform float eq2;          // bazik 3 band equalizer medium value 0.0 to 1.0
uniform float eq3;          // bazik 3 band equalizer high value 0.0 to 1.0
uniform float banger;       // bazik music banger (beat detect) 0.0 to 1.0

uniform int breaker;        // bazik user control 0 or 1
uniform int mode;           // bazik user control 1,2,3,4,5,6,7 or 8

uniform float par1;         // bazik user control -1.0 to 1.0
uniform float par2;         // bazik user control -1.0 to 1.0



// ----------------------------------------------------
// Be carefull, a bad shader can crash your computer !
// ----------------------------------------------------

/**
 
 By @Eiyeron
 Based on Illogical from Matrefeytontias, plane deformations on TI-83/84 http://www.omnimaga.org/index.php/
 
 Transform by taktik for Bazik. http://bazik-vj.com
 
 **/


#define SPEED 0.00001
#define PI 3.1415
#define TAU (PI*2.0)
#define THREE_D_VALUE 10.



//#define MOVE
#define ROTATE


float getCheckerboardColor( vec2 position ) {
	float  xpos = floor( (1.0 + par1) * 20.0 * position.x );
	float  ypos = floor( (1.0 + par2) * 10.0 * position.y );
	float col = mod( xpos, 2.0 );
    if (breaker == 0) {
        if( mod( ypos, 2.0 ) > 0.0) {
            col = cos(xpos*ypos + eq2 * 5.);
        } else {
            col = sin(xpos*ypos + time * 5. );
            
        }
    }
    else {
        col = cos(xpos*ypos + time/3.0 + eq3 * 0.8);
    }
	return col;
}

vec3 shader(vec2 pos) {
	// Normalize coords from 0->1 with 0.5, 0.5 at center.
	vec2 position = 2.0 * pos.xy / resolution.xy - 1.0;
	position.x *= resolution.x / resolution.y; // Correct aspect ratio.
	
	// Some calculations.
	float r = length(position);
	float a = atan(position.y, position.x);
	// Transition factor
	float factor = sin(time) /2. + 0.5;
    
#ifdef ROTATE
	a+= sin(time /20.);
#endif
	
	// THe magic happens right here.
	float u = position.x,v = position.y;
    
    
    
if (mode == 8) {
	u = position.x/abs(position.y) ;
	v = 1./abs(position.y);
    }

else if (mode == 2) {
	u = position.x/abs(position.y) ;
	v = cos(u)/abs(position.y);
    }

else if (mode == 3) {
	u = a;
	v = 1./r;
    }

else if (mode == 4) {
	u = factor*(position.x/abs(position.y)) + (1.-factor)*(a);
	v = factor*(1./abs(position.y)) + (1.-factor)*(1./r);
    }

else if (mode == 5) {
	u = a;
	v = 1./(r + sin(r + time));
    }

else if (mode == 6) {
	u = r * cos(a + r);
	v = r * sin(a + r);
    }
    
    vec2 p = vec2(u, v);
if (mode == 7) {
	// Make that move! :p
	p += vec2( SPEED * cos(time), SPEED * time );
}
	
	vec3 color = vec3(1.0);
    

    if (v < (resolution.y * 0.00002)) {
        color *= vec3(color2.x*0.8, color2.y*0.8,color2.z*0.8);
    }
    else if (v < (resolution.y * 0.0004)){
        color *= vec3(color3.x*1.0, color3.y*1.0,color3.z*1.0);
    }
    else {
        color *= vec3(color2.x*0.8, color2.y*0.8,color2.z*0.8);
    }
    
    
    color *= color1;

	// Get the checkerboard motif
	color *= vec3(getCheckerboardColor( p ));

	// Use v and r to create a little distance fog.

	color *= 1./v;
	color *= 2.-r;
    
	return color;
	
}

void main( void ) {

	vec3 color;

	//color = vec3(shader(gl_FragCoord.xy + vec2(RGB_D_VALUE, 0.)).r, shader(gl_FragCoord.xy + vec2(0.,-RGB_D_VALUE)).g, shader(gl_FragCoord.xy + vec2(0.,RGB_D_VALUE)).b);

	vec2 position = 2.0 * gl_FragCoord.xy / resolution.xy - 1.0;
	position.x *= resolution.x / resolution.y; // Correct aspect ratio.
	color = vec3(shader(gl_FragCoord.xy + vec2(THREE_D_VALUE*length(position),0.)).r,
		     shader(gl_FragCoord.xy).g,
		     shader(gl_FragCoord.xy + vec2(-THREE_D_VALUE*length(position),0.)).b);


    if (breaker == 1) {
        // Little scanline effect
        color *= 1. * mod(gl_FragCoord.y, 4.);
    }


	// Let's fill the screen with eyecandy!
	gl_FragColor = vec4( color, 1.0 );
}
