uniform float time;         // bazik preset playback time in seconds
uniform vec2 resolution;    // bazik render width (x) & height (y)

uniform vec3 color1;        // bazik user color 1 (r=x, g=y, b=z)
uniform vec3 color2;        // bazik user color 2 (r=x, g=y, b=z)
uniform vec3 color3;        // bazik user color 3 (r=x, g=y, b=z)
uniform vec3 color4;        // bazik user color 4 (r=x, g=y, b=z)

uniform float eq1;          // bazik 3 band equalizer bass value 0.0 to 1.0
uniform float eq2;          // bazik 3 band equalizer medium value 0.0 to 1.0
uniform float eq3;          // bazik 3 band equalizer high value 0.0 to 1.0
uniform float banger;       // bazik music banger (beat detect) 0.0 to 1.0

uniform int breaker;        // bazik user control 0 or 1
uniform int mode;           // bazik old user control 1,2,3,4,5,6,7 or 8
uniform float shift;        // bazik user shift random value 0.0 to 1.0

uniform float par1;         // bazik user control -1.0 to 1.0
uniform float par2;         // bazik user control -1.0 to 1.0

// http://glslsandbox.com/e#20474.0
// By: Brandon Fogerty
// bfogerty at gmail dot com

void main( void )
{
	vec2 p = ( gl_FragCoord.xy / resolution.xy ) * 2.0 - (shift * 2.0);
	
	vec3 c = vec3( color4.x* 0.5, color4.y* 0.5, color4.z * 0.5 );
    
    
	
	float amplitude = 0.2 * (par1 + 1.1);
	float glowT = sin(time) * shift + ((0.5 * par2 + 1.1));
    if(breaker == 1) glowT = eq1 * 0.9 + 0.1;
	float glowFactor = mix( 0.15, 0.45, glowT );
    
    if(mode == 1 || mode == 3 || mode == 5 || mode == 7 ){
        c += vec3(color1.x* 0.1, color1.y* 0.1, color1.z* 0.1) * ( glowFactor * abs( 1.0 / sin(p.x + sin( p.y + time ) * (eq1*amplitude) ) ));
        c += vec3(color2.x* 0.2, color2.y* 0.2, color2.z* 0.2) * ( glowFactor * abs( 1.0 / sin(p.x + sin( p.y + time+1.00 ) * (eq2*amplitude) + 0.1 ) ));
        c += vec3(color3.x* 0.3, color3.y* 0.3, color3.z* 0.3) * ( glowFactor * abs( 1.0 / sin(p.x + sin( p.y + time+2.00 ) * (eq3*amplitude) + 0.2 ) ));
    }
    else {
        c += vec3(color1.x* 0.1, color1.y* 0.1, color1.z* 0.1) * ( glowFactor * abs( 1.0 / sin(p.y + sin( p.x + time ) * (eq1*amplitude)  ) ));
        c += vec3(color2.x* 0.2, color2.y* 0.2, color2.z* 0.2) * ( glowFactor * abs( 1.0 / sin(p.y + sin( p.x + time+1.00 ) * (eq2*amplitude) + 0.1 ) ));
        c += vec3(color3.x* 0.3, color3.y* 0.3, color3.z* 0.3) * ( glowFactor * abs( 1.0 / sin(p.y + sin( p.x + time+2.00 ) * (eq3*amplitude) + 0.2 ) ));
    }
    
    c = c * (eq1 + eq1 + eq2 + eq3) * 0.2;
    
	gl_FragColor = vec4( c, 1.0 );
    
}